@@ -48,7 +48,7 @@ async def test_auto_apis(transactional_db, easy_api_client):
 
         response = await client.delete("/", query=dict(pk=200))
         assert response.status_code == 200
-        assert response.json()["data"] == {"Detail": "Not found."}
+        assert response.json()["code"] == 404
 
 
 async def test_auto_generation_settings(settings):
